RunnerClient

Trait RunnerClient 

pub trait RunnerClient: Send {
    // Required methods
    fn list(&self, owner: &str, repo: &str) -> Result<Vec<Runner>>;
    fn show(&self, owner: &str, repo: &str, id: &str) -> Result<Runner>;
    fn remove(&self, owner: &str, repo: &str, id: &str) -> Result<()>;
    fn reset_token(&self, owner: &str, repo: &str, id: &str) -> Result<String>;
    fn pause(&self, owner: &str, repo: &str, id: &str) -> Result<()>;
    fn resume(&self, owner: &str, repo: &str, id: &str) -> Result<()>;
    fn registration_token(
        &self,
        owner: &str,
        repo: &str,
    ) -> Result<RegistrationToken>;
}

Required Methods

fn list(&self, owner: &str, repo: &str) -> Result<Vec<Runner>>

fn show(&self, owner: &str, repo: &str, id: &str) -> Result<Runner>

fn remove(&self, owner: &str, repo: &str, id: &str) -> Result<()>

fn reset_token(&self, owner: &str, repo: &str, id: &str) -> Result<String>

Reset the runner’s authentication token; returns the new token the operator must paste into the runner’s config.

fn pause(&self, owner: &str, repo: &str, id: &str) -> Result<()>

fn resume(&self, owner: &str, repo: &str, id: &str) -> Result<()>

fn registration_token( &self, owner: &str, repo: &str, ) -> Result<RegistrationToken>

Obtain a short-lived registration token. torii runner register uses it to wrap the platform’s CLI (gitlab-runner register, ./config.sh on GitHub Actions). Returns (token, register_url) — the URL is the value the CLI wants for its --url arg.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors