pub fn send_empty(req: RequestBuilder, ctx: &str) -> Result<()>Expand description
Send a request and ignore the response body, only checking status. Used for cancel / retry / delete style operations.
pub fn send_empty(req: RequestBuilder, ctx: &str) -> Result<()>Send a request and ignore the response body, only checking status. Used for cancel / retry / delete style operations.