pub fn drop_token_cache()Expand description
Public variant used by callers that mutated auth.toml out-of-band
(e.g. the TUI’s auth ops spawn a child process via torii auth oauth … — the child invalidates its own cache when it calls
set_token, but the parent TUI has no way of knowing that
without an explicit cue). Call this after any operation that
could have changed a token outside this process.